/*
 * Copyright 2020-2022 Google LLC
 * Copyright 2020-2022 EPAM Systems, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.provider.gcp.encryption;

import org.opengroup.osdu.core.common.provider.interfaces.IKmsClient;
import org.springframework.security.crypto.encrypt.Encryptors;
import org.springframework.security.crypto.encrypt.TextEncryptor;

public class AnthosKmsClient implements IKmsClient {

  private final TextEncryptor encryptor;

  public AnthosKmsClient(AnthosKmsProperties anthosKmsProperties) {
    this.encryptor = Encryptors.text(anthosKmsProperties.getKmsPassword(),
        anthosKmsProperties.getKmsSalt());
  }

  @Override
  public String encryptString(String s) {
    return this.encryptor.encrypt(s);
  }

  @Override
  public String decryptString(String s) {
    return this.encryptor.decrypt(s);
  }
}
