/* Licensed Materials - Property of IBM              */		
/* (c) Copyright IBM Corp. 2020. All Rights Reserved.*/	

package org.opengroup.osdu.register.provider.ibm.subscriber;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import lombok.RequiredArgsConstructor;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.core.common.model.notification.Topic;
import org.opengroup.osdu.register.provider.interfaces.subscriber.ITopicsRepository;
import org.opengroup.osdu.register.utils.FileUtil;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Repository;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;

@Repository
@Primary
@RequiredArgsConstructor
public class TopicsRepositoryImpl implements ITopicsRepository {

    private final JaxRsDpsLog log;
    private final DpsHeaders headers;
    private Map<String, List<Topic>> topicsMap = new HashMap<>();

    public List<Topic> listMessages() {
        final String partitionId = headers.getPartitionId();
        if (topicsMap.containsKey(partitionId)) {
            return topicsMap.get(partitionId);
        }

        final List<Topic> template = getTopicTemplate();

        topicsMap.put(partitionId, template);
        return template;
    }

    List<Topic> getTopicTemplate() {
        Type type = new TypeToken<ArrayList<Topic>>() {
        }.getType();
        return new Gson().fromJson(FileUtil.readFile("topics.json", log), type);
    }
}
